# -*- coding: utf-8 -*-
"""
    Testing settings
    -------------------------------
    
"""
from .production import *


